# Peplum ChangeLog

## v0.2.0

**Released: 2025-01-27**

- Worked around a likely Textual bug that caused an occasional cosmetic
  problem with the main PEPs list.
  ([#6](https://github.com/davep/peplum/pull/6))
- Added the created date of a PEP to the list of things searched when doing
  a free text search. ([#7](https://github.com/davep/peplum/pull/7))
- Commands in the Python version filtering palette are now sorted by proper
  version order. ([#12](https://github.com/davep/peplum/pull/12))
- Added the ability to attach notes to a PEP.
  ([#13](https://github.com/davep/peplum/pull/13))

## v0.1.0

**Released: 2025-01-25**

- Initial release.

## v0.0.1

**Released: 2025-01-14**

- Initial placeholder package to test that the name is available in PyPI.

[//]: # (ChangeLog.md ends here)
